@@ -7,10 +7,10 @@ class Singleton(metaclass=utilitools.singleton):
 
 
 class Test(unittest.TestCase):
-    def test_same_object(self):
-        instance_x = Singleton()
-        instance_y = Singleton()
-        self.assertIs(instance_x, instance_y)
+    def test_singleton(self):
+        actual = Singleton()
+        expected = Singleton()
+        self.assertIs(expected, actual)
 
 
 if __name__ == '__main__':
